/// <reference types="node" />
import { ClippingMask, Document, Ellipse, Layer, Polygon, TextLayer } from "../../internal";
import { AlignOptions } from "./align";
import { ExportTypes, Format, Output, PathOrWithMetadataOptions } from "./exportTo";
export declare type AnyLayer = BaseLayer | Layer | TextLayer | Polygon | Ellipse | ClippingMask;
interface Rotate {
    type: "rotate";
    degrees: number;
}
interface Resize {
    type: "resize";
    width?: number;
    height?: number;
}
interface Reflect {
    type: "reflect";
    direction: "vertical" | "horizontal";
}
interface Hue {
    type: "hue";
    degrees: number;
}
interface Saturation {
    type: "saturation";
    amount: number;
}
interface Brightness {
    type: "brightness";
    amount: number;
}
interface Hue {
    type: "hue";
    degrees: number;
}
interface Invert {
    type: "invert";
}
interface Blur {
    type: "blur";
    sigma: number;
}
declare type Edit = Rotate | Resize | Reflect | Hue | Saturation | Brightness | Invert | Blur;
export declare type BlendMode = "normal" | "darken" | "multiply" | "colorBurn" | "lighten" | "screen" | "colorDodge" | "linearDodge" | "overlay" | "softLight" | "hardLight" | "difference" | "exclusion";
export interface BaseLayerData {
    name: string;
    file?: string;
    buffer?: Buffer;
    svg?: string;
    left?: number;
    top?: number;
    position?: number;
    debugMode?: boolean;
}
export default class BaseLayer {
    document?: Document;
    name: string;
    left: number;
    top: number;
    get position(): number;
    _edits: Edit[];
    opacity: number;
    blendMode: BlendMode;
    debugMode: boolean;
    constructor(baseLayerData: BaseLayerData, document?: Document);
    duplicate: (name?: string | undefined, position?: number | undefined, debugMode?: boolean | undefined) => Promise<this>;
    move: (position: number, relative?: boolean | undefined) => number;
    translate: (left?: number | undefined, top?: number | undefined) => this;
    translateBy: (x?: number | undefined, y?: number | undefined) => this;
    align: (alignOptions?: AlignOptions | undefined) => this;
    rotate: (degrees: number) => this;
    resize: (width?: number | null | undefined, height?: number | null | undefined) => this;
    resizeBy: (width?: number | null | undefined, height?: number | null | undefined, scale?: boolean | undefined) => this;
    reflect: (direction: "vertical" | "horizontal") => this;
    setOpacity: (opacity: number) => this;
    setBlendMode: (blendMode?: "normal" | "darken" | "multiply" | "colorBurn" | "lighten" | "screen" | "colorDodge" | "linearDodge" | "overlay" | "softLight" | "hardLight" | "difference" | "exclusion" | null | undefined) => this;
    hue: (degrees: number) => this;
    saturation: (amount: number) => this;
    brightness: (amount: number) => this;
    grayscale: () => this;
    invert: () => this;
    blur: (sigma: number) => this;
    circularMask: (name: string, keepSource?: boolean | undefined) => ClippingMask;
    remove: () => void;
    rasterize: () => Promise<Layer>;
    exportTo: <ExportType extends ExportTypes, PathOrWithMetadata extends PathOrWithMetadataOptions = false>(format: Format, exportType: ExportType, pathOrWithMetadata?: PathOrWithMetadata | undefined) => Promise<Output<ExportType, PathOrWithMetadata>>;
    setDebugMode: (debugMode: boolean) => boolean;
    _debug: (info: string) => void;
}
export {};
