"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("../../debug"));
const align_1 = __importDefault(require("./align"));
const blur_1 = __importDefault(require("./blur"));
const brightness_1 = __importDefault(require("./brightness"));
const circularMask_1 = __importDefault(require("./circularMask"));
const duplicate_1 = __importDefault(require("./duplicate"));
const exportTo_1 = __importDefault(require("./exportTo"));
const grayscale_1 = __importDefault(require("./grayscale"));
const hue_1 = __importDefault(require("./hue"));
const invert_1 = __importDefault(require("./invert"));
const move_1 = __importDefault(require("./move"));
const rasterize_1 = __importDefault(require("./rasterize"));
const reflect_1 = __importDefault(require("./reflect"));
const remove_1 = __importDefault(require("./remove"));
const resize_1 = __importDefault(require("./resize"));
const resizeBy_1 = __importDefault(require("./resizeBy"));
const rotate_1 = __importDefault(require("./rotate"));
const saturation_1 = __importDefault(require("./saturation"));
const setBlendMode_1 = __importDefault(require("./setBlendMode"));
const setOpacity_1 = __importDefault(require("./setOpacity"));
const translate_1 = __importDefault(require("./translate"));
const translateBy_1 = __importDefault(require("./translateBy"));
class BaseLayer {
    constructor(baseLayerData, document) {
        this.duplicate = (name, position, debugMode) => duplicate_1.default(this, name, position, debugMode);
        this.move = (position, relative) => move_1.default(this, position, relative);
        this.translate = (left, top) => translate_1.default(this, left, top);
        this.translateBy = (x, y) => translateBy_1.default(this, x, y);
        this.align = (alignOptions) => align_1.default(this, alignOptions);
        this.rotate = (degrees) => rotate_1.default(this, degrees);
        this.resize = (width, height) => resize_1.default(this, width, height);
        this.resizeBy = (width, height, scale) => resizeBy_1.default(this, width, height, scale);
        this.reflect = (direction) => reflect_1.default(this, direction);
        this.setOpacity = (opacity) => setOpacity_1.default(this, opacity);
        this.setBlendMode = (blendMode) => setBlendMode_1.default(this, blendMode);
        this.hue = (degrees) => hue_1.default(this, degrees);
        this.saturation = (amount) => saturation_1.default(this, amount);
        this.brightness = (amount) => brightness_1.default(this, amount);
        this.grayscale = () => grayscale_1.default(this);
        this.invert = () => invert_1.default(this);
        this.blur = (sigma) => blur_1.default(this, sigma);
        this.circularMask = (name, keepSource) => circularMask_1.default(this, name, keepSource);
        this.remove = () => remove_1.default(this);
        this.rasterize = () => rasterize_1.default(this);
        this.exportTo = (format, exportType, pathOrWithMetadata) => exportTo_1.default(this, format, exportType, pathOrWithMetadata);
        this.setDebugMode = (debugMode) => this.debugMode = debugMode;
        this._debug = (info) => debug_1.default(info, this);
        this.document = document;
        this.name = baseLayerData.name;
        this.left = baseLayerData.left || 0;
        this.top = baseLayerData.top || 0;
        this._edits = [];
        this.opacity = 100;
        this.blendMode = "normal";
        this.setDebugMode(baseLayerData.debugMode || false);
        if (document)
            document.addLayer(this, baseLayerData.position);
    }
    get position() {
        return this.document ? this.document.layers.findIndex((l) => l === this) : 0;
    }
}
exports.default = BaseLayer;
