"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_1 = require("../../internal");
function align(layer, alignOptions = {}) {
    if ((!(layer instanceof internal_1.Layer)) && (!(layer instanceof internal_1.ShapeLayer)))
        throw new Error("This layer can't be aligned");
    if (!layer.document)
        throw new Error("This layer isn't a part of a document");
    let left;
    if (alignOptions.left === "start")
        left = 0;
    else if ((alignOptions.left === "center") || (!alignOptions.left))
        left = Math.round((layer.document.width / 2) - (layer.width / 2));
    else if (alignOptions.left === "end")
        left = layer.document.width - layer.width;
    else
        throw new Error("Invalid left align type");
    let top;
    if (alignOptions.top === "start")
        top = 0;
    else if ((alignOptions.top === "center") || (!alignOptions.top))
        top = Math.round((layer.document.height / 2) - (layer.height / 2));
    else if (alignOptions.top === "end")
        top = layer.document.height - layer.height;
    else
        throw new Error("Invalid top align type");
    let leftOffset = alignOptions.leftOffset || 0;
    if (alignOptions.leftOffsetUnits === "percent")
        leftOffset = layer.document.width * (leftOffset / 100);
    let topOffset = alignOptions.topOffset || 0;
    if (alignOptions.topOffsetUnits === "percent")
        topOffset = layer.document.height * (topOffset / 100);
    if (alignOptions.leftOffset)
        left = left + leftOffset;
    if (alignOptions.topOffset)
        top = top + topOffset;
    layer._debug(`Aligning to ${alignOptions.left || "center"} (left) and ${alignOptions.top || "center"} (top) with an offset of ${leftOffset}px (left) and ${topOffset}px (top)`);
    layer.translate(left, top);
    return layer;
}
exports.default = align;
