"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_1 = require("../../internal");
async function duplicate(layer, name, position, debugMode) {
    layer._debug(`Duplicating to '${name || layer.name}' at position ${position || layer.position + 1}`);
    let duplicatedLayer;
    if (layer instanceof internal_1.TextLayer)
        duplicatedLayer = new internal_1.TextLayer({
            name: name || layer.name,
            text: {
                text: layer.text,
                font: layer.font,
                fontSize: layer.fontSize,
                fontWeight: layer.fontWeight,
                textAlign: layer.textAlign,
                color: layer.color,
                lineHeight: layer.lineHeight,
                maxWidth: layer.maxWidth
            },
            left: layer.left,
            top: layer.top,
            position: position || layer.position + 1,
            debugMode
        }, layer.document);
    else if (layer instanceof internal_1.Polygon)
        duplicatedLayer = new internal_1.Polygon({
            name: name || layer.name,
            shape: {
                width: layer.width,
                height: layer.height,
                sides: layer.sides,
                fill: layer.fill,
                stroke: layer.stroke,
                strokeWidth: layer.strokeWidth
            },
            left: layer.left,
            top: layer.top,
            position: position || layer.position + 1,
            debugMode
        }, layer.document);
    else if (layer instanceof internal_1.Ellipse)
        duplicatedLayer = new internal_1.Ellipse({
            name: name || layer.name,
            shape: {
                width: layer.width,
                height: layer.height,
                fill: layer.fill,
                stroke: layer.stroke,
                strokeWidth: layer.strokeWidth
            },
            left: layer.left,
            top: layer.top,
            position: position || layer.position + 1,
            debugMode
        }, layer.document);
    else if (layer instanceof internal_1.ClippingMask)
        duplicatedLayer = new internal_1.ClippingMask({
            name: name || layer.name,
            mask: layer.mask,
            source: layer.source,
            position: position || layer.position + 1,
            debugMode
        }, layer.document);
    else {
        duplicatedLayer = new internal_1.Layer({
            name: name || layer.name,
            left: layer.left,
            top: layer.top,
            position: position || layer.position + 1,
            debugMode
        }, layer.document, layer._inputData);
        await duplicatedLayer._initialize;
    }
    duplicatedLayer._edits = [...layer._edits];
    duplicatedLayer.opacity = layer.opacity;
    duplicatedLayer.blendMode = layer.blendMode;
    return duplicatedLayer;
}
exports.default = duplicate;
