"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sharp_1 = __importDefault(require("sharp"));
const internal_1 = require("../../internal");
async function exportTo(baseLayer, format, exportType, pathOrWithMetadata) {
    if (!["png", "jpeg"].includes(format))
        throw new Error("Invalid format");
    if (!["file", "buffer"].includes(exportType))
        throw new Error("Invalid export type");
    baseLayer._debug(`Exporting as ${exportType}${exportType === "file" ? ` to ${pathOrWithMetadata}` : ""}`);
    let inputData;
    if (baseLayer instanceof internal_1.Layer)
        inputData = baseLayer._inputData;
    if ((baseLayer instanceof internal_1.Polygon) || (baseLayer instanceof internal_1.Ellipse))
        inputData = baseLayer.toBuffer();
    if (baseLayer instanceof internal_1.TextLayer)
        inputData = await baseLayer.toBuffer();
    if (baseLayer instanceof internal_1.ClippingMask)
        inputData = await baseLayer.toBuffer();
    let canvas = sharp_1.default(inputData);
    for (let edit of baseLayer._edits) {
        if (edit.type === "rotate")
            canvas.rotate(edit.degrees, {
                background: { r: 0, g: 0, b: 0, alpha: 0 }
            });
        else if (edit.type === "resize")
            canvas.resize(edit.width, edit.height, {
                fit: "fill"
            });
        else if (edit.type === "reflect")
            edit.direction === "vertical" ? canvas.flip() : canvas.flop();
        else if (edit.type === "hue")
            canvas.modulate({ hue: edit.degrees });
        else if (edit.type === "saturation")
            canvas.modulate({ saturation: edit.amount / 100 });
        else if (edit.type === "brightness")
            canvas.modulate({ brightness: edit.amount / 100 });
        else if (edit.type === "invert")
            canvas.negate();
        else if (edit.type === "blur")
            canvas.blur(edit.sigma);
        const exported = await canvas.toFormat("png").toBuffer();
        canvas = sharp_1.default(exported);
    }
    if (baseLayer.opacity !== 100)
        canvas.composite([{
                input: Buffer.from([255, 255, 255, 255 * (baseLayer.opacity / 100)]),
                raw: {
                    width: 1,
                    height: 1,
                    channels: 4
                },
                tile: true,
                blend: "dest-in"
            }]);
    canvas.toFormat(format);
    if (exportType === "file") {
        if (typeof pathOrWithMetadata !== "string")
            throw new Error("Path must be specified if exportType is 'file'");
        await canvas.toFile(pathOrWithMetadata);
        return undefined;
    }
    const exported = await canvas.toBuffer({ resolveWithObject: true });
    if (pathOrWithMetadata)
        return {
            data: exported.data,
            width: exported.info.width,
            height: exported.info.height
        };
    return exported.data;
}
exports.default = exportTo;
