import { AnyLayer, ClippingMask, ClippingMaskData, Ellipse, EllipseData, Layer, LayerData, Polygon, PolygonData, TextLayer, TextLayerData } from "../../internal";
import { ExportTypes, Format, Output, PathOrWithMetadataOptions } from "../BaseLayer/exportTo";
export interface DocumentData {
    name?: string;
    width: number;
    height: number;
    debugMode?: boolean;
}
export default class Document {
    name: string;
    width: number;
    height: number;
    layers: AnyLayer[];
    debugMode: boolean;
    constructor(documentData: DocumentData);
    createLayer: (layerData: LayerData) => Promise<Layer>;
    createPolygon: (polygonData: PolygonData) => Polygon;
    createEllipse: (ellipseData: EllipseData) => Ellipse;
    createTextLayer: (textLayerData: TextLayerData) => TextLayer;
    createClippingMask: (clippingMaskData: ClippingMaskData) => ClippingMask;
    addLayer: (layer: AnyLayer, position?: number | undefined) => void;
    getLayer: (nameOrIndex: string | number) => AnyLayer | undefined;
    mergeLayers: (name: string, layers?: (string | number | import("../BaseLayer/BaseLayer").default | Layer | ClippingMask | TextLayer | Polygon | Ellipse)[] | undefined, copy?: boolean | undefined) => Promise<Layer>;
    exportTo: <ExportType extends ExportTypes, PathOrWithMetadata extends PathOrWithMetadataOptions = false>(format: Format, exportType: ExportType, pathOrWithMetadata?: PathOrWithMetadata | undefined) => Promise<Output<ExportType, PathOrWithMetadata>>;
    setDebugMode: (debugMode: boolean) => boolean;
    _debug: (info: string) => void;
}
