"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("../../debug"));
const addLayer_1 = __importDefault(require("./addLayer"));
const createClippingMask_1 = __importDefault(require("./createClippingMask"));
const createEllipse_1 = __importDefault(require("./createEllipse"));
const createLayer_1 = __importDefault(require("./createLayer"));
const createPolygon_1 = __importDefault(require("./createPolygon"));
const createTextLayer_1 = __importDefault(require("./createTextLayer"));
const exportTo_1 = __importDefault(require("./exportTo"));
const mergeLayers_1 = __importDefault(require("./mergeLayers"));
class Document {
    constructor(documentData) {
        this.createLayer = (layerData) => createLayer_1.default(this, layerData);
        this.createPolygon = (polygonData) => createPolygon_1.default(this, polygonData);
        this.createEllipse = (ellipseData) => createEllipse_1.default(this, ellipseData);
        this.createTextLayer = (textLayerData) => createTextLayer_1.default(this, textLayerData);
        this.createClippingMask = (clippingMaskData) => createClippingMask_1.default(this, clippingMaskData);
        this.addLayer = (layer, position) => addLayer_1.default(this, layer, position);
        this.getLayer = (nameOrIndex) => {
            if (typeof nameOrIndex === "string")
                return this.layers.find((l) => l.name === nameOrIndex);
            else if (typeof nameOrIndex === "number")
                return this.layers[nameOrIndex];
        };
        this.mergeLayers = (name, layers, copy) => mergeLayers_1.default(this, name, layers, copy);
        this.exportTo = (format, exportType, pathOrWithMetadata) => exportTo_1.default(this, format, exportType, pathOrWithMetadata);
        this.setDebugMode = (debugMode) => this.debugMode = debugMode;
        this._debug = (info) => debug_1.default(info, this);
        this.name = documentData.name || "Unnamed Document";
        this.width = documentData.width;
        this.height = documentData.height;
        this.layers = [];
        this.setDebugMode(documentData.debugMode || false);
    }
}
exports.default = Document;
