"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("paths-js/path"));
const color_1 = require("../../color");
function polygonSVG(polygonShapeData) {
    const centerX = polygonShapeData.width / 2;
    const centerY = polygonShapeData.height / 2;
    const radius = Math.min(centerX, centerY);
    const degrees = 360 / polygonShapeData.sides;
    let path = path_1.default();
    for (let i = 0; i < polygonShapeData.sides; i++) {
        const degree = degrees * i;
        const angle = degree * (Math.PI / 180);
        const x = radius * Math.cos(angle);
        const y = radius * Math.sin(angle);
        if (i === 0)
            path = path.moveto(x + radius, y + radius);
        else
            path = path.lineto(x + radius, y + radius);
    }
    path = path.rotate(-90, radius, radius);
    const generatedLeft = Math.min(...path.points().map((p) => p[0]));
    const generatedTop = Math.min(...path.points().map((p) => p[1]));
    path = path.translate(-generatedLeft, -generatedTop);
    const generatedWidth = Math.max(...path.points().map((p) => p[0]));
    const generatedHeight = Math.max(...path.points().map((p) => p[1]));
    path = path.scale(polygonShapeData.width / generatedWidth, polygonShapeData.height / generatedHeight);
    if (polygonShapeData.strokeWidth)
        path = path.translate(polygonShapeData.strokeWidth / 2, polygonShapeData.strokeWidth / 2);
    const svgCode = `
        <svg viewBox="0 0 ${polygonShapeData.width + (polygonShapeData.strokeWidth || 0)} ${polygonShapeData.height + (polygonShapeData.strokeWidth || 0)}" xmlns="http://www.w3.org/2000/svg">
            <polygon points="${path.points().map((p) => p.join(",")).join(" ")}"${polygonShapeData.fill ? ` fill="${color_1.parseColor(polygonShapeData.fill)}"` : ""}${polygonShapeData.stroke ? ` stroke="${color_1.parseColor(polygonShapeData.stroke)}"` : ""}${polygonShapeData.strokeWidth ? ` stroke-width="${polygonShapeData.strokeWidth}"` : ""} />
        </svg>
    `;
    return svgCode.trim();
}
exports.default = polygonSVG;
