/// <reference types="node" />
import { Color } from "../../color";
import { BaseLayer, Document } from "../../internal";
export declare const DEFAULT_FONT_SIZE = 24;
export declare type TextAlign = "left" | "center" | "right" | "justify";
export interface TextData {
    text: string;
    font?: string;
    fontSize?: number;
    fontWeight?: string;
    textAlign?: TextAlign;
    color?: Color;
    lineHeight?: number;
    maxWidth?: number;
}
export interface TextLayerData {
    name: string;
    text: TextData;
    left?: number;
    top?: number;
    position?: number;
    debugMode?: boolean;
}
export default class TextLayer extends BaseLayer {
    text: string;
    font?: string;
    fontSize: number;
    fontWeight?: string;
    textAlign: TextAlign;
    color: string;
    lineHeight?: number;
    maxWidth: number;
    constructor(textLayerData: TextLayerData, document?: Document);
    setText: (text: string) => TextLayer;
    setFont: (font?: string | undefined) => TextLayer;
    setFontSize: (fontSize?: number | undefined) => TextLayer;
    setFontWeight: (fontWeight?: string | undefined) => TextLayer;
    setTextAlign: (textAlign?: "center" | "left" | "right" | "justify" | undefined) => TextLayer;
    setColor: (color?: string | number | import("../../color").RGBA | undefined) => TextLayer;
    setLineHeight: (lineHeight?: number | undefined) => TextLayer;
    setMaxWidth: (maxWidth?: number | undefined) => TextLayer;
    static textBuffer: (textData: TextData) => Promise<Buffer>;
    toBuffer: () => Promise<Buffer>;
}
