"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const canvas_1 = __importDefault(require("canvas"));
const sharp_1 = __importDefault(require("sharp"));
const text_to_image_1 = __importDefault(require("text-to-image"));
const color_1 = require("../../color");
const internal_1 = require("../../internal");
async function textBuffer(textData) {
    if (!textData.fontSize)
        textData.fontSize = internal_1.DEFAULT_FONT_SIZE;
    let fontName = textData.font;
    if ((textData.font) && (textData.font.includes("."))) {
        fontName = Buffer.from(textData.font).toString("base64");
        canvas_1.default.registerFont(textData.font, { family: fontName });
    }
    const options = { bgColor: "#00000000" };
    if (fontName)
        options.fontFamily = `"${fontName}"`;
    options.fontSize = textData.fontSize;
    if (textData.fontWeight)
        options.fontWeight = textData.fontWeight;
    options.textAlign = textData.textAlign || "left";
    options.textColor = color_1.parseColor(textData.color || "#000000");
    options.lineHeight = textData.lineHeight || (textData.fontSize * 1.5);
    if (textData.maxWidth)
        options.maxWidth = textData.maxWidth;
    const imageData = await text_to_image_1.default.generate(textData.text, options);
    const image = imageData.split(",").slice(1).join(",");
    const textImage = Buffer.from(image, "base64");
    const buffer = await sharp_1.default(textImage)
        .trim()
        .toFormat("png")
        .toBuffer();
    return buffer;
}
exports.default = textBuffer;
